| Title: | R Bindings for EvalHyd |
|---|---|
| Description: | An evaluator for probabilistic and deterministic streamflow predictions. |
| Authors: | Thibault Hallouin [aut] (ORCID: <https://orcid.org/0000-0003-0144-2989>), François Bourgin [aut, cre] (ORCID: <https://orcid.org/0000-0002-2820-7260>) |
| Maintainer: | François Bourgin <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.1.3.0 |
| Built: | 2026-05-25 07:23:22 UTC |
| Source: | https://gitlab.irstea.fr/HYCAR-Hydro/evalhyd/evalhyd-r |
Deterministic evaluation
evald( q_obs, q_prd, metrics, q_thr = NULL, events = NULL, transform = NULL, exponent = NULL, epsilon = NULL, t_msk = NULL, m_cdt = NULL, bootstrap = NULL, dts = NULL, seed = NULL, diagnostics = NULL )evald( q_obs, q_prd, metrics, q_thr = NULL, events = NULL, transform = NULL, exponent = NULL, epsilon = NULL, t_msk = NULL, m_cdt = NULL, bootstrap = NULL, dts = NULL, seed = NULL, diagnostics = NULL )
q_obs |
A numeric vector (or numeric matrix) of streamflow observations. |
q_prd |
A numeric vector (or numeric matrix) of streamflow predictions. |
metrics |
A string vector of evaluation metrics to be computed. |
q_thr |
A numeric vector (or numeric matrix) of streamflow thresholds. |
events |
A string specifying the type of streamflow events to consider for threshold exceedance-based metrics. |
transform |
A string specifying the transformation to apply to both streamflow observations and predictions. |
exponent |
A numeric scalar specifying the value of the exponent n to use when the transform is the power function. |
epsilon |
A numeric scalar specifying the value of the small constant to add to both the streamflow observations and predictions. |
t_msk |
A logical array of mask(s). |
m_cdt |
A string array of masking condition(s). |
bootstrap |
A list providing the parameters of the bootstrapping method. |
dts |
A string vector of corresponding dates and times. |
seed |
An integer value for the seed used by random generators. |
diagnostics |
A string vector of evaluation diagnostics to be computed. |
Probabilistic evaluation
evalp( q_obs, q_prd, metrics, q_thr = NULL, events = NULL, c_lvl = NULL, q_lvl = NULL, t_msk = NULL, m_cdt = NULL, bootstrap = NULL, dts = NULL, seed = NULL, diagnostics = NULL )evalp( q_obs, q_prd, metrics, q_thr = NULL, events = NULL, c_lvl = NULL, q_lvl = NULL, t_msk = NULL, m_cdt = NULL, bootstrap = NULL, dts = NULL, seed = NULL, diagnostics = NULL )
q_obs |
A numeric vector (or numeric matrix) of streamflow observations. |
q_prd |
A numeric vector (or numeric matrix) of streamflow predictions. |
metrics |
A string vector of evaluation metrics to be computed. |
q_thr |
A numeric vector (or numeric matrix) of streamflow thresholds. |
events |
A string specifying the type of streamflow events to consider for threshold exceedance-based metrics. |
c_lvl |
A numeric vector containing the confidence interval(s). |
q_lvl |
A numeric vector containing the quantile level(s). |
t_msk |
A logical array of mask(s). |
m_cdt |
A string array of masking condition(s). |
bootstrap |
A list providing the parameters of the bootstrapping method. |
dts |
A string vector of corresponding dates and times. |
seed |
An integer value for the seed used by random generators. |
diagnostics |
A string vector of evaluation diagnostics to be computed. |